@@ -16,7 +16,4 @@ except ImportError:
         subprocess.check_call(['pip', 'install', 'PPshare'])
         print('安装成功！您已经可以正常使用PPtool了')
     else:
-        print('取消安装PPshare。')
-
-df = get_method('企业')
-print(df)
\ No newline at end of file
+        print('取消安装PPshare。')
\ No newline at end of file
